@@ -1,22 +1,19 @@
 package Class::PObject::Driver::sqlite;
 
-# $Id: sqlite.pm,v 1.10 2003/11/07 04:51:04 sherzodr Exp $
+# $Id: sqlite.pm,v 1.5 2003/08/27 00:23:37 sherzodr Exp $
 
 use strict;
-#use diagnostics;
 use Log::Agent;
 use vars ('@ISA', '$VERSION');
-require File::Path;
-require File::Basename;
 require Class::PObject::Driver::DBI;
 
 @ISA = ('Class::PObject::Driver::DBI');
-$VERSION = '2.01';
+$VERSION = '2.00';
 
 
 sub save {
     my ($self, $object_name, $props, $columns) = @_;
-    
+
     my $dbh                 = $self->dbh($object_name, $props)        or return;
     my $table               = $self->_tablename($object_name, $props, $dbh) or return;
     my ($sql, $bind_params);
@@ -52,19 +49,10 @@ sub dbh {
     my ($self, $object_name, $props) = @_;
 
     my $datasource = $props->{datasource};
+
     if ( defined $self->stash($datasource) ) {
         return $self->stash($datasource)
     }
-    
-    my $basedir = File::Basename::dirname( $datasource );
-    logtrc 3, "datasource:%s, directory: %s", $datasource, $basedir;
-
-    unless ( -e $basedir ) {
-        unless ( File::Path::mkpath($basedir) ) {
-            $self->errstr( "couldn't create '$basedir': $!" );
-            return undef
-        }
-    }
     require DBI;
     my $dbh = DBI->connect("dbi:SQLite:dbname=$datasource", "", "", {RaiseError=>0, PrintError=>0});
     unless ( defined $dbh ) {
@@ -85,26 +73,18 @@ sub _tablename {
 
     my $table_name = lc $object_name;
     $table_name =~ s/\W+/_/g;
-    
-    {
-        local $^W = 0; # DBD::SQLite generates a warning
-        my %tables = map { $_, 1 } $dbh->tables;
-        if ( $tables{ $table_name } ) {
-            return $table_name
-        }
-    }
-
-    my $sql = $self->_prepare_create_table($object_name, $table_name);
-    unless ( $dbh->do( $sql ) ) {
-        $self->errstr( $dbh->errstr );
-        return undef
-    }
     return $table_name
 }
 
+
+
+
+
 1;
 __END__;
 
+=pod
+
 =head1 NAME
 
 Class::PObject::Driver::sqlite - SQLite Pobject Driver
@@ -118,6 +98,7 @@ Class::PObject::Driver::sqlite - SQLite Pobject Driver
         datasource => 'data/website.db'
     };
 
+
 =head1 DESCRIPTION
 
 Class::PObject::Driver::sqlite is a direct subclass of L<Class::PObjecet::Driver::DBI|Class::PObject::Driver::DBI>.
@@ -147,24 +128,20 @@ C<save()> - stores/updates the object
 
 =back
 
-=head1 NOTES
-
-If the directory portion of the I<datasource> is missing, it will attempt to
-create necessary directory tree for you.
-
-If table to store the database is found to be missing, it will attempt to create
-the a proper table for you. To have more control over how it creates this table,
-you can fill-in column types using I<tmap> argument.
-
 =head1 SEE ALSO
 
-L<Class::PObject>, 
-L<Class::PObject::Driver::csv>,
-L<Class::PObject::Driver::file>, 
-L<Class::PObject::Driver::mysql>
+L<Class::PObject>, L<Class::PObject::Driver::csv>,
+L<Class::PObject::Driver::file>, L<Class::PObject::Driver::mysql>
+
+=head1 AUTHOR
+
+Sherzod Ruzmetov E<lt>sherzodr@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
