@@ -1,13 +1,12 @@
 package Class::PObject::Iterator;
 
-# $Id: Iterator.pm,v 1.5.2.2 2003/09/06 10:14:56 sherzodr Exp $
+# $Id: Iterator.pm,v 1.2 2003/08/26 19:56:30 sherzodr Exp $
 
 use strict;
-#use diagnostics;
 use Carp 'croak';
 use vars ('$VERSION');
 
-$VERSION = '1.00';
+$VERSION = '0.01';
 
 sub new {
     my $class = shift;
@@ -16,7 +15,7 @@ sub new {
     my $self = {
         pobject     => $_[0],
         data_set    => $_[1],
-        next_ptr=> 0,
+        next_pointer=> 0,
         last_ptr    =>  scalar(@{$_[1]})-1
     };
 
@@ -26,6 +25,7 @@ sub new {
 sub DESTROY { 
     my $self = shift;
 
+    $self->finish()
 }
 
 sub next {
@@ -42,6 +42,7 @@ sub next {
 
 sub size {
     my $self = shift;
+
     return $self->{last_ptr} - $self->{next_ptr} + 1
 }
 
@@ -69,7 +70,8 @@ sub push {
 sub finish {
     my $self = shift;
 
-    $self->{data_set} = []
+    $self->{data_set} = undef;
+    $self->{pobject}  = undef;
 }
 
 
@@ -82,8 +84,11 @@ sub dump {
     return $d->Dump
 }
 
+
+
 1;
 __END__
+# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -92,7 +97,7 @@ Class::PObject::Iterator - Incremental object loader for Class::PObject
 =head1 SYNOPSIS
 
     use Class::PObject::Iterator;
-    my $iter = new Class::PObject::Iterator($class, \@ids);
+    my $iter = new Class::PObject::Iterator($driver, \@ids);
 
     while ( my $obj = $iter->fetch ) {
         ...
@@ -108,7 +113,7 @@ on a pobject.
 
 =over 4
 
-=item C<new($class, \@ids)>
+=item C<new($pobject, \@ids)>
 
 Constructor method. Accepts two arguments - name of the class, and list of ids.
 Returns Class::PObject::Iterator object. You normally never will have to call C<new()>
@@ -151,12 +156,20 @@ and want to start from clean data set:
 
 =back
 
+
 =head1 SEE ALSO
 
 L<Class::PObject>
 
+=head1 AUTHOR
+
+Sherzod B. Ruzmetov, E<lt>sherzodr@cpan.orgE<gt>
+
 =head1 COPYRIGHT AND LICENSE
 
-For author and copyright information refer to Class::PObject's L<online manual|Class::PObject>.
+Copyright 2003 by Sherzod B. Ruzmetov.
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself.
 
 =cut
